===============
Getting started
===============

Installation
------------
- Windows installers for PyScanFCS are available at the `release page <https://github.com/FCS-analysis/PyScanFCS/releases>`_.
- On Debian-based systems, install via ``apt-get install pyscanfcs``.
- If you have Python 3.6 installed, you may install PyScanFCS via ``pip install pyscanfcs``.
  After the installation, type ``pyscanfcs`` in a command shell to start PyScanFCS.


Documentation
-------------
The documentation is in the process of being transferred entirely to
readthedocs.org. Currently, the it is scattered across several
places and it might be outdated:

- Original LaTeX-based PDF file: https://github.com/FCS-analysis/PyScanFCS/wiki/PyScanFCS_doc.pdf
- Book chapter in *Methods in Molecular Biology* (2013) on perpendicular line scanning FCS: https://arxiv.org/abs/1806.00070
